:py:mod:`sink_template_worker`
==============================

.. py:module:: sink_template_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   sink_template_worker.initialise
   sink_template_worker.work_function
   sink_template_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   sink_template_worker.current_dir
   sink_template_worker.current_dir
   sink_template_worker.need_parameters
   sink_template_worker.global_var_1
   sink_template_worker.global_var_2
   sink_template_worker.global_var_3
   sink_template_worker.global_var_4
   sink_template_worker.vis
   sink_template_worker.worker_object


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: need_parameters
   :annotation: = True

   

.. py:data:: global_var_1
   :annotation: :str

   

.. py:data:: global_var_2
   :annotation: :str

   

.. py:data:: global_var_3
   :annotation: :float

   

.. py:data:: global_var_4
   :annotation: :int

   

.. py:data:: vis
   :annotation: :Heron.gui.visualisation_dpg.VisualisationDPG

   

.. py:function:: initialise(_worker_object)


.. py:function:: work_function(data, parameters, savenodestate_update_substate_df)


.. py:function:: on_end_of_life()


.. py:data:: worker_object
   

   

